@@ -23,6 +23,7 @@ import salt.utils.files
 import salt.utils.path
 import salt.utils.verify
 import salt.utils.yaml
+from salt.utils.immutabletypes import freeze
 
 from saltfactories.exceptions import FactoryNotStarted
 from saltfactories.exceptions import FactoryTimeout
@@ -349,11 +350,14 @@ class DaemonFactory(SubprocessFactoryBase):
     before_terminate_callbacks = attr.ib(repr=False, hash=False, default=attr.Factory(list))
     after_start_callbacks = attr.ib(repr=False, hash=False, default=attr.Factory(list))
     after_terminate_callbacks = attr.ib(repr=False, hash=False, default=attr.Factory(list))
+    extra_cli_arguments_after_first_start_failure = attr.ib(hash=False, default=attr.Factory(list))
 
     def __attrs_post_init__(self):
         super().__attrs_post_init__()
         if self.check_ports and not isinstance(self.check_ports, (list, tuple)):
             self.check_ports = [self.check_ports]
+        self.register_after_start_callback(self._add_factory_to_stats_processes)
+        self.register_after_terminate_callback(self._remove_factory_from_stats_processes)
 
     def register_before_start_callback(self, callback, *args, **kwargs):
         self.before_start_callbacks.append((callback, args, kwargs))
@@ -403,19 +407,28 @@ class DaemonFactory(SubprocessFactoryBase):
         start_time = time.time()
         start_attempts = max_start_attempts or self.max_start_attempts
         current_attempt = 0
-        while current_attempt <= start_attempts:
-            current_attempt += 1
+        run_arguments = list(extra_cli_arguments)
+        while True:
             if process_running:
                 break
+            current_attempt += 1
+            if current_attempt > start_attempts:
+                break
             log.info("Starting %s. Attempt: %d of %d", self, current_attempt, start_attempts)
             current_start_time = time.time()
             start_running_timeout = current_start_time + (start_timeout or self.start_timeout)
-            self._run(*extra_cli_arguments)
+            if current_attempt > 1 and self.extra_cli_arguments_after_first_start_failure:
+                run_arguments = list(extra_cli_arguments) + list(
+                    self.extra_cli_arguments_after_first_start_failure
+                )
+            self._run(*run_arguments)
             if not self.is_running():
                 # A little breathe time to allow the process to start if not started already
                 time.sleep(0.5)
             while time.time() <= start_running_timeout:
                 if not self.is_running():
+                    log.warning("%s is no longer running", self)
+                    self.terminate()
                     break
                 if self.run_start_checks(current_start_time, start_running_timeout) is False:
                     time.sleep(1)
@@ -442,20 +455,11 @@ class DaemonFactory(SubprocessFactoryBase):
                         exc,
                         exc_info=True,
                     )
-            if self.factories_manager and self.factories_manager.stats_processes is not None:
-                self.factories_manager.stats_processes[self.get_display_name()] = psutil.Process(
-                    self.pid
-                )
             return process_running
         result = self.terminate()
         raise FactoryNotStarted(
             "The {} factory has failed to confirm running status after {} attempts, which "
-            "took {:.2f} seconds({:.2f} seconds each)".format(
-                self,
-                current_attempt - 1,
-                time.time() - start_time,
-                start_timeout or self.start_timeout,
-            ),
+            "took {:.2f} seconds".format(self, current_attempt - 1, time.time() - start_time,),
             stdout=result.stdout,
             stderr=result.stderr,
             exitcode=result.exitcode,
@@ -501,20 +505,38 @@ class DaemonFactory(SubprocessFactoryBase):
     def run_start_checks(self, started_at, timeout_at):
         check_ports = set(self.get_check_ports())
         if not check_ports:
+            log.debug("No ports to check connection to for %s", self)
             return True
         checks_start_time = time.time()
         while time.time() <= timeout_at:
             if not self.is_running():
-                log.info("%s is no longer running", self)
+                log.warning("%s is no longer running", self)
                 return False
             if not check_ports:
                 break
             check_ports -= ports.get_connectable_ports(check_ports)
         else:
-            log.error("Failed to check ports after %1.2f seconds", time.time() - checks_start_time)
+            log.error(
+                "Failed to check ports after %1.2f seconds for %s",
+                time.time() - checks_start_time,
+                self,
+            )
             return False
+        log.debug(
+            "Successfuly connected to all ports(%s) for %s", set(self.get_check_ports()), self
+        )
         return True
 
+    def _add_factory_to_stats_processes(self):
+        if self.factories_manager and self.factories_manager.stats_processes is not None:
+            display_name = self.get_display_name()
+            self.factories_manager.stats_processes[display_name] = psutil.Process(self.pid)
+
+    def _remove_factory_from_stats_processes(self):
+        if self.factories_manager and self.factories_manager.stats_processes is not None:
+            display_name = self.get_display_name()
+            self.factories_manager.stats_processes.pop(display_name, None)
+
     def __enter__(self):
         if not self.is_running():
             raise RuntimeError(
@@ -557,14 +579,15 @@ class SaltFactory:
         self.config_file = self.config["conf_file"]
         self.config_dir = os.path.dirname(self.config_file)
         self.id = self.config["id"]
+        self.config = freeze(self.config)
 
     def get_display_name(self):
         """
         Returns a human readable name for the factory
         """
         if self.display_name is None:
-            self.display_name = self.cli_script_name
-        return self.display_name
+            self.display_name = "{}(id={!r})".format(self.__class__.__name__, self.id)
+        return super().get_display_name()
 
 
 @attr.s(kw_only=True)
@@ -747,8 +770,13 @@ class SaltDaemonFactory(SaltFactory, DaemonFactory):
     def __attrs_post_init__(self):
         DaemonFactory.__attrs_post_init__(self)
         SaltFactory.__attrs_post_init__(self)
-        if self.display_name is None:
-            self.display_name = self.id
+        for arg in self.extra_cli_arguments_after_first_start_failure:
+            if arg in ("-l", "--log-level"):
+                break
+            if arg.startswith("--log-level="):
+                break
+        else:
+            self.extra_cli_arguments_after_first_start_failure.append("--log-level=debug")
 
     @classmethod
     def configure(
@@ -831,6 +859,7 @@ class SaltDaemonFactory(SaltFactory, DaemonFactory):
 
         check_events = set(self.get_check_events())
         if not check_events:
+            log.debug("No events to listen to for %s", self)
             return True
         checks_start_time = time.time()
         while time.time() <= timeout_at:
@@ -841,8 +870,15 @@ class SaltDaemonFactory(SaltFactory, DaemonFactory):
                 break
             check_events -= self.event_listener.get_events(check_events, after_time=started_at)
         else:
-            log.error("Failed to check events after %1.2f seconds", time.time() - checks_start_time)
+            log.error(
+                "Failed to check events after %1.2f seconds for %s",
+                time.time() - checks_start_time,
+                self,
+            )
             return False
+        log.debug(
+            "Successfuly checked for all events(%s) for %s", set(self.get_check_events()), self
+        )
         return True
 
     def build_cmdline(self, *args):
