@@ -11,17 +11,13 @@ Salt Factories Manager
 import logging
 import pathlib
 import sys
-import weakref
 
 import attr
 
 import saltfactories
-from saltfactories.factories import cli
 from saltfactories.factories import daemons
 from saltfactories.utils import cli_scripts
-from saltfactories.utils import event_listener
 from saltfactories.utils import running_username
-from saltfactories.utils.ports import get_unused_localhost_port
 
 log = logging.getLogger(__name__)
 
@@ -38,8 +34,6 @@ class FactoriesManager:
     If process statistics are enabled, it also adds the started daemons to those statistics.
 
     Args:
-        pytestconfig (:fixture:`pytestconfig`):
-            PyTest `pytestconfig` fixture
         root_dir:
         log_server_port(int):
             The port the log server should listen at
@@ -71,11 +65,10 @@ class FactoriesManager:
             hook accessible at `stats_processes` on the `session` attribute of the :fixture:`request`.
     """
 
-    pytestconfig = attr.ib(repr=False)
     root_dir = attr.ib()
-    log_server_port = attr.ib(default=None)
-    log_server_level = attr.ib(default=None)
-    log_server_host = attr.ib(default=None)
+    log_server_port = attr.ib()
+    log_server_level = attr.ib()
+    log_server_host = attr.ib()
     code_dir = attr.ib(default=None)
     inject_coverage = attr.ib(default=False)
     inject_sitecustomize = attr.ib(default=False)
@@ -83,22 +76,15 @@ class FactoriesManager:
     environ = attr.ib(default=None)
     slow_stop = attr.ib(default=True)
     start_timeout = attr.ib(default=None)
-    stats_processes = attr.ib(default=None)
+    stats_processes = attr.ib(repr=False, default=None)
+    event_listener = attr.ib(repr=False)
 
     # Internal attributes
-    cache = attr.ib(default=None, init=False, repr=False)
     scripts_dir = attr.ib(default=None, init=False, repr=False)
-    event_listener = attr.ib(default=None, init=False, repr=False)
 
     def __attrs_post_init__(self):
         self.root_dir = pathlib.Path(self.root_dir.strpath)
         self.root_dir.mkdir(exist_ok=True)
-        if self.log_server_port is None:
-            self.log_server_port = get_unused_localhost_port()
-        if self.log_server_level is None:
-            self.log_server_level = "error"
-        if self.log_server_host is None:
-            self.log_server_host = "localhost"
         if self.start_timeout is None:
             if not sys.platform.startswith(("win", "darwin")):
                 self.start_timeout = 30
@@ -109,26 +95,6 @@ class FactoriesManager:
         # Setup the internal attributes
         self.scripts_dir = self.root_dir / "scripts"
         self.scripts_dir.mkdir(exist_ok=True)
-        self.cache = {
-            "api": weakref.WeakValueDictionary(),
-            "cloud": weakref.WeakValueDictionary(),
-            "masters": weakref.WeakValueDictionary(),
-            "minions": weakref.WeakValueDictionary(),
-            "syndics": weakref.WeakValueDictionary(),
-            "proxy-minions": weakref.WeakValueDictionary(),
-            "factories": weakref.WeakValueDictionary(),
-        }
-        self.event_listener = event_listener.EventListener(
-            auth_events_callback=self._handle_auth_event
-        )
-        self.event_listener.start()
-
-    def __enter__(self):
-        self.event_listener.start()
-        yield self
-
-    def __exit__(self, *exc):
-        self.event_listener.stop()
 
     @staticmethod
     def get_salt_log_handlers_path():
@@ -200,7 +166,7 @@ class FactoriesManager:
         self,
         master_id,
         order_masters=False,
-        master_of_masters_id=None,
+        master_of_masters=None,
         config_defaults=None,
         config_overrides=None,
         max_start_attempts=3,
@@ -217,8 +183,9 @@ class FactoriesManager:
             order_masters(bool):
                 Boolean flag to set if this master is going to control other masters(ie, master of masters), like,
                 for example, in a :ref:`Syndic <salt:syndic>` topology scenario
-            master_of_masters_id(str):
-                The master of masters ID, like, for example, in a :ref:`Syndic <salt:syndic>` topology scenario
+            master_of_masters(:py:class:`saltfactories.factories.daemons.master.SaltMasterFactory`):
+                A :py:class:`saltfactories.factories.daemons.master.SaltMasterFactory` instance, like, for example,
+                in a :ref:`Syndic <salt:syndic>` topology scenario
             config_defaults(dict):
                 A dictionary of default configuration to use when configuring the master
             config_overrides(dict):
@@ -232,11 +199,7 @@ class FactoriesManager:
             :py:class:`saltfactories.factories.daemons.master.SaltMasterFactory`:
                 The master process class instance
         """
-        if master_id in self.cache["masters"]:
-            log.info("Returning cached salt master factory with the ID: %s", master_id)
-            return self.cache["masters"][master_id]
-
-        root_dir = self._get_root_dir_for_daemon(master_id, config_defaults=config_defaults)
+        root_dir = self.get_root_dir_for_daemon(master_id, config_defaults=config_defaults)
         config = factory_class.configure(
             self,
             master_id,
@@ -244,6 +207,7 @@ class FactoriesManager:
             config_defaults=config_defaults,
             config_overrides=config_overrides,
             order_masters=order_masters,
+            master_of_masters=master_of_masters,
         )
         self.final_master_config_tweaks(config)
         loaded_config = factory_class.write_config(config)
@@ -251,7 +215,6 @@ class FactoriesManager:
             "salt-master",
             loaded_config,
             factory_class,
-            "masters",
             master_id,
             max_start_attempts,
             start_timeout,
@@ -261,7 +224,7 @@ class FactoriesManager:
     def get_salt_minion_daemon(
         self,
         minion_id,
-        master_id=None,
+        master=None,
         config_defaults=None,
         config_overrides=None,
         max_start_attempts=3,
@@ -275,8 +238,9 @@ class FactoriesManager:
         Args:
             minion_id(str):
                 The minion ID
-            master_id(str):
-                The master ID this minion will connect to.
+            master(:py:class:`saltfactories.factories.daemons.master.SaltMasterFactory`):
+                An instance of :py:class:`saltfactories.factories.daemons.master.SaltMasterFactory` that
+                this minion will connect to.
             config_defaults(dict):
                 A dictionary of default configuration to use when configuring the minion
             config_overrides(dict):
@@ -290,11 +254,7 @@ class FactoriesManager:
             :py:class:`~saltfactories.factories.daemons.minion.SaltMinionFactory`:
                 The minion process class instance
         """
-        if minion_id in self.cache["minions"]:
-            log.info("Returning cached salt minion factory with the ID: %s", minion_id)
-            return self.cache["minions"][minion_id]
-
-        root_dir = self._get_root_dir_for_daemon(minion_id, config_defaults=config_defaults)
+        root_dir = self.get_root_dir_for_daemon(minion_id, config_defaults=config_defaults)
 
         config = factory_class.configure(
             self,
@@ -302,7 +262,7 @@ class FactoriesManager:
             root_dir=root_dir,
             config_defaults=config_defaults,
             config_overrides=config_overrides,
-            master_id=master_id,
+            master=master,
         )
         self.final_minion_config_tweaks(config)
         loaded_config = factory_class.write_config(config)
@@ -310,7 +270,6 @@ class FactoriesManager:
             "salt-minion",
             loaded_config,
             factory_class,
-            "minions",
             minion_id,
             max_start_attempts,
             start_timeout,
@@ -320,13 +279,17 @@ class FactoriesManager:
     def get_salt_syndic_daemon(
         self,
         syndic_id,
-        master_of_masters_id=None,
+        master_of_masters=None,
         config_defaults=None,
         config_overrides=None,
         max_start_attempts=3,
         start_timeout=None,
         factory_class=daemons.syndic.SaltSyndicFactory,
+        master_config_defaults=None,
+        master_config_overrides=None,
         master_factory_class=daemons.master.SaltMasterFactory,
+        minion_config_defaults=None,
+        minion_config_overrides=None,
         minion_factory_class=daemons.minion.SaltMinionFactory,
         **factory_class_kwargs
     ):
@@ -337,9 +300,9 @@ class FactoriesManager:
             syndic_id(str):
                 The Syndic ID. This ID will be shared by the ``salt-master``, ``salt-minion`` and ``salt-syndic``
                 processes.
-            master_of_masters_id(str):
-                The master of masters ID that the master configured in this :ref:`Syndic <salt:syndic>` topology
-                scenario shall connect to.
+            master_of_masters(:py:class:`saltfactories.factories.daemons.master.SaltMasterFactory`):
+                An instance of :py:class:`saltfactories.factories.daemons.master.SaltMasterFactory` that the
+                master configured in this :ref:`Syndic <salt:syndic>` topology scenario shall connect to.
             config_defaults(dict):
                 A dictionary of default configurations with three top level keys, ``master``, ``minion`` and
                 ``syndic``, to use when configuring the  ``salt-master``, ``salt-minion`` and ``salt-syndic``
@@ -357,102 +320,69 @@ class FactoriesManager:
             :py:class:`~saltfactories.factories.daemons.syndic.SaltSyndicFactory`:
                 The syndic process class instance
         """
-        if syndic_id in self.cache["syndics"]:
-            log.info("Returning cached syndic factory with the ID: %s", syndic_id)
-            return self.cache["syndics"][syndic_id]
-        elif syndic_id in self.cache["masters"]:
-            raise RuntimeError(
-                "A master by the ID of '{}' was already configured".format(syndic_id)
-            )
-        elif syndic_id in self.cache["minions"]:
-            raise RuntimeError(
-                "A minion by the ID of '{}' was already configured".format(syndic_id)
-            )
 
-        defaults_and_overrides_top_level_keys = {"master", "minion", "syndic"}
-
-        if config_defaults:
-            if not set(config_defaults).issubset(defaults_and_overrides_top_level_keys):
-                raise RuntimeError(
-                    "The config_defaults keyword argument must only contain 3 top level keys: {}".format(
-                        ", ".join(defaults_and_overrides_top_level_keys)
-                    )
-                )
-
-        if config_overrides:
-            if not set(config_overrides).issubset(defaults_and_overrides_top_level_keys):
-                raise RuntimeError(
-                    "The config_overrides keyword argument must only contain 3 top level keys: {}".format(
-                        ", ".join(defaults_and_overrides_top_level_keys)
-                    )
-                )
-
-        root_dir = self._get_root_dir_for_daemon(
-            syndic_id, config_defaults=config_defaults.get("syndic") if config_defaults else None
-        )
-
-        master_of_masters = syndic_master_port = None
-        if master_of_masters_id is not None:
-            master_of_masters = self.cache["masters"].get(master_of_masters_id)
-            if master_of_masters is None:
-                raise RuntimeError("No config found for {}".format(master_of_masters_id))
-
-        syndic_setup_config = factory_class.default_config(
-            root_dir,
-            syndic_id=syndic_id,
-            config_defaults=config_defaults,
-            config_overrides=config_overrides,
-            syndic_master_port=syndic_master_port,
-        )
+        root_dir = self.get_root_dir_for_daemon(syndic_id, config_defaults=config_defaults)
 
         master_config = master_factory_class.configure(
-            self, syndic_id, root_dir=root_dir, config_overrides=syndic_setup_config["master"]
+            self,
+            syndic_id,
+            root_dir=root_dir,
+            config_defaults=master_config_defaults,
+            config_overrides=master_config_overrides,
+            master_of_masters=master_of_masters,
         )
+        # Remove syndic related options
+        for key in list(master_config):
+            if key.startswith("syndic_"):
+                master_config.pop(key)
         self.final_master_config_tweaks(master_config)
         master_loaded_config = master_factory_class.write_config(master_config)
-        if master_of_masters:
-            master_loaded_config["pytest-master"]["master_config"] = master_of_masters.config
         master_factory = self._get_factory_class_instance(
             "salt-master",
             master_loaded_config,
             master_factory_class,
-            "masters",
             syndic_id,
             max_start_attempts,
             start_timeout,
         )
 
         minion_config = minion_factory_class.configure(
-            self, syndic_id, root_dir=root_dir, config_overrides=syndic_setup_config["minion"]
+            self,
+            syndic_id,
+            root_dir=root_dir,
+            config_defaults=minion_config_defaults,
+            config_overrides=minion_config_overrides,
+            master=master_factory,
         )
         self.final_minion_config_tweaks(minion_config)
         minion_loaded_config = minion_factory_class.write_config(minion_config)
-        minion_loaded_config["pytest-minion"]["master_config"] = master_loaded_config
         minion_factory = self._get_factory_class_instance(
             "salt-minion",
             minion_loaded_config,
             minion_factory_class,
-            "minions",
             syndic_id,
             max_start_attempts,
             start_timeout,
         )
 
-        syndic_config = syndic_setup_config["syndic"]
+        syndic_config = factory_class.default_config(
+            root_dir,
+            syndic_id=syndic_id,
+            config_defaults=config_defaults,
+            config_overrides=config_overrides,
+            master_of_masters=master_of_masters,
+        )
         self.final_syndic_config_tweaks(syndic_config)
         syndic_loaded_config = factory_class.write_config(syndic_config)
-        if master_of_masters:
-            syndic_loaded_config["pytest-syndic"]["master_config"] = master_of_masters.config
-        # Just to get info about the master running along with the syndic
-        syndic_loaded_config["pytest-syndic"]["syndic_master"] = syndic_loaded_config
         factory = self._get_factory_class_instance(
             "salt-syndic",
             syndic_loaded_config,
             factory_class,
-            "syndics",
             syndic_id,
             max_start_attempts=max_start_attempts,
             start_timeout=start_timeout,
+            master=master_factory,
+            minion=minion_factory,
             **factory_class_kwargs
         )
 
@@ -464,7 +394,7 @@ class FactoriesManager:
     def get_salt_proxy_minion_daemon(
         self,
         proxy_minion_id,
-        master_id=None,
+        master=None,
         config_defaults=None,
         config_overrides=None,
         max_start_attempts=3,
@@ -478,8 +408,9 @@ class FactoriesManager:
         Args:
             proxy_minion_id(str):
                 The proxy minion ID
-            master_id(str):
-                The master ID this minion will connect to.
+            master(:py:class:`saltfactories.factories.daemons.master.SaltMasterFactory`):
+                An instance of :py:class:`saltfactories.factories.daemons.master.SaltMasterFactory` that this minion
+                will connect to.
             config_defaults(dict):
                 A dictionary of default configuration to use when configuring the proxy minion
             config_overrides(dict):
@@ -494,11 +425,7 @@ class FactoriesManager:
             :py:class:`~saltfactories.factories.daemons.proxy.SaltProxyMinionFactory`:
                 The proxy minion process class instance
         """
-        if proxy_minion_id in self.cache["proxy-minions"]:
-            log.info("Returning cached salt proxy minion factory with the ID: %s", proxy_minion_id)
-            return self.cache["proxy-minions"][proxy_minion_id]
-
-        root_dir = self._get_root_dir_for_daemon(proxy_minion_id, config_defaults=config_defaults)
+        root_dir = self.get_root_dir_for_daemon(proxy_minion_id, config_defaults=config_defaults)
 
         config = factory_class.configure(
             self,
@@ -506,7 +433,7 @@ class FactoriesManager:
             root_dir=root_dir,
             config_defaults=config_defaults,
             config_overrides=config_overrides,
-            master_id=master_id,
+            master=master,
         )
         self.final_proxy_minion_config_tweaks(config)
         loaded_config = factory_class.write_config(config)
@@ -514,7 +441,6 @@ class FactoriesManager:
             "salt-proxy",
             loaded_config,
             factory_class,
-            "proxy-minions",
             proxy_minion_id,
             max_start_attempts,
             start_timeout,
@@ -523,11 +449,7 @@ class FactoriesManager:
 
     def get_salt_api_daemon(
         self,
-        master_id,
-        order_masters=False,
-        master_of_masters_id=None,
-        config_defaults=None,
-        config_overrides=None,
+        master,
         max_start_attempts=3,
         start_timeout=None,
         factory_class=daemons.api.SaltApiFactory,
@@ -543,282 +465,24 @@ class FactoriesManager:
             :py:class:`~saltfactories.factories.daemons.api.SaltApiFactory`:
                 The salt-api process class instance
         """
-        if master_id in self.cache["api"]:
-            log.info("Returning cached salt api factory with the ID: %s", master_id)
-            return self.cache["api"][master_id]
-
-        master = self.cache["masters"].get(master_id)
-        if master is None:
-            master = self.get_salt_master_daemon(
-                master_id,
-                order_masters=order_masters,
-                master_of_masters_id=master_of_masters_id,
-                config_defaults=config_defaults,
-                config_overrides=config_overrides,
-            )
         return self._get_factory_class_instance(
             "salt-api",
             master.config,
             factory_class,
-            "api",
-            master_id,
+            master.id,
             max_start_attempts=max_start_attempts,
             start_timeout=start_timeout,
             **factory_class_kwargs
         )
 
-    def get_salt_cloud_cli(
-        self,
-        master_id,
-        config_defaults=None,
-        config_overrides=None,
-        max_start_attempts=3,
-        start_timeout=None,
-        factory_class=cli.cloud.SaltCloudFactory,
-        **factory_class_kwargs
-    ):
-        """
-        Return a salt-cloud CLI instance
-
-        Args:
-            master_id(str):
-                The master ID this salt-cloud will interact with.
-            config_defaults(dict):
-                A dictionary of default configuration to use when configuring the minion
-            config_overrides(dict):
-                A dictionary of configuration overrides to use when configuring the minion
-            max_start_attempts(int):
-                How many attempts should be made to start the minion in case of failure to validate that its running
-            factory_class_kwargs(dict):
-                Extra keyword arguments to pass to :py:class:`~saltfactories.factories.cli.cloud.SaltCloudFactory`
-
-        Returns:
-            :py:class:`~saltfactories.factories.cli.cloud.SaltCloudFactory`:
-                The salt-cloud CLI script process class instance
-        """
-
-        if master_id in self.cache["cloud"]:
-            log.info("Returning cached salt cloud factory with the ID: %s", master_id)
-            return self.cache["cloud"][master_id]
-
-        master = self.cache["masters"].get(master_id)
-        if master is None:
-            master = self.get_salt_master_daemon(
-                master_id, max_start_attempts=max_start_attempts, start_timeout=start_timeout
-            )
-
-        root_dir = pathlib.Path(master.config["root_dir"])
-
-        config = factory_class.configure(
-            self,
-            master_id,
-            root_dir=root_dir,
-            config_defaults=config_defaults,
-            config_overrides=config_overrides,
-        )
-        self.final_cloud_config_tweaks(config)
-        config = factory_class.write_config(config)
-
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt-cloud",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        factory = factory_class(cli_script_name=script_path, config=config, **factory_class_kwargs)
-        self.cache["cloud"][master_id] = factory
-        return factory
-
-    def get_salt_client(
-        self,
-        master_id,
-        functions_known_to_return_none=None,
-        factory_class=cli.client.SaltClientFactory,
-    ):
-        """
-        Return a local salt client object
-        """
-        return factory_class(
-            master_config=self.cache["masters"][master_id].config.copy(),
-            functions_known_to_return_none=functions_known_to_return_none,
-        )
-
-    def get_salt_cli(
-        self, master_id, factory_class=cli.salt.SaltCliFactory, **factory_class_kwargs
-    ):
-        """
-        Return a `salt` CLI process
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        return factory_class(
-            cli_script_name=script_path,
-            config=self.cache["masters"][master_id].config,
-            **factory_class_kwargs
-        )
-
-    def get_salt_call_cli(
-        self, minion_id, factory_class=cli.call.SaltCallCliFactory, **factory_class_kwargs
-    ):
-        """
-        Return a `salt-call` CLI process
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt-call",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        try:
-            return factory_class(
-                cli_script_name=script_path,
-                config=self.cache["minions"][minion_id].config,
-                **factory_class_kwargs
-            )
-        except KeyError:
-            try:
-                return factory_class(
-                    cli_script_name=script_path,
-                    base_script_args=["--proxyid={}".format(minion_id)],
-                    config=self.cache["proxy-minions"][minion_id].config,
-                    **factory_class_kwargs
-                )
-            except KeyError:
-                raise KeyError(
-                    "Could not find {} in the minions or proxy minions caches".format(minion_id)
-                )
-
-    def get_salt_run_cli(
-        self, master_id, factory_class=cli.run.SaltRunCliFactory, **factory_class_kwargs
-    ):
-        """
-        Return a `salt-run` CLI process
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt-run",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        return factory_class(
-            cli_script_name=script_path,
-            config=self.cache["masters"][master_id].config,
-            **factory_class_kwargs
-        )
-
-    def get_salt_cp_cli(
-        self, master_id, factory_class=cli.cp.SaltCpCliFactory, **factory_class_kwargs
-    ):
-        """
-        Return a `salt-cp` CLI process
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt-cp",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        return factory_class(
-            cli_script_name=script_path,
-            config=self.cache["masters"][master_id].config,
-            **factory_class_kwargs
-        )
-
-    def get_salt_key_cli(
-        self, master_id, factory_class=cli.key.SaltKeyCliFactory, **factory_class_kwargs
-    ):
-        """
-        Return a `salt-key` CLI process
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt-key",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        return factory_class(
-            cli_script_name=script_path,
-            config=self.cache["masters"][master_id].config,
-            **factory_class_kwargs
-        )
-
-    def get_salt_spm_cli(
-        self, master_id, factory_class=cli.spm.SpmCliFactory, **factory_class_kwargs
-    ):
-        """
-        Return a salt `spm` CLI process
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "spm",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        return factory_class(
-            cli_script_name=script_path,
-            config=self.cache["masters"][master_id].config,
-            **factory_class_kwargs
-        )
-
-    def get_salt_ssh_cli(
-        self,
-        master_id,
-        factory_class=cli.ssh.SaltSshCliFactory,
-        roster_file=None,
-        target_host=None,
-        client_key=None,
-        ssh_user=None,
-        **factory_class_kwargs
-    ):
-        """
-        Return a `salt-ssh` CLI process
-
-        Args:
-            roster_file(str):
-                The roster file to use
-            target_host(str):
-                The target host address to connect to
-            client_key(str):
-                The path to the private ssh key to use to connect
-            ssh_user(str):
-                The remote username to connect as
-        """
-        script_path = cli_scripts.generate_script(
-            self.scripts_dir,
-            "salt-ssh",
-            code_dir=self.code_dir,
-            inject_coverage=self.inject_coverage,
-            inject_sitecustomize=self.inject_sitecustomize,
-        )
-        return factory_class(
-            cli_script_name=script_path,
-            config=self.cache["masters"][master_id].config,
-            roster_file=roster_file,
-            target_host=target_host,
-            client_key=client_key,
-            ssh_user=ssh_user or running_username(),
-            **factory_class_kwargs
-        )
-
     def get_sshd_daemon(
         self,
-        daemon_id,
         config_dir=None,
         listen_address=None,
         listen_port=None,
         sshd_config_dict=None,
         display_name=None,
+        cli_script_name="sshd",
         max_start_attempts=3,
         start_timeout=None,
         factory_class=daemons.sshd.SshdDaemonFactory,
@@ -828,10 +492,6 @@ class FactoriesManager:
         Start an sshd daemon
 
         Args:
-            request(:fixture:`request`):
-                The PyTest test execution request
-            daemon_id(str):
-                An ID so we know about the sshd server by ID
             max_start_attempts(int):
                 How many attempts should be made to start the proxy minion in case of failure to validate that
                 its running
@@ -843,6 +503,8 @@ class FactoriesManager:
                 The port where the sshd server will listen to connections
             sshd_config_dict(dict):
                 A dictionary of key-value pairs to construct the sshd config file
+            cli_script_name(str):
+                The name or path to the binary to run. Defaults to ``sshd``.
             factory_class_kwargs(dict):
                 Extra keyword arguments to pass to :py:class:`~saltfactories.factories.daemons.sshd.SshdDaemonFactory`
 
@@ -851,20 +513,20 @@ class FactoriesManager:
                 The sshd process class instance
         """
         if config_dir is None:
-            config_dir = self._get_root_dir_for_daemon(daemon_id)
+            config_dir = self.get_root_dir_for_daemon("sshd")
         try:
             config_dir = pathlib.Path(config_dir.strpath).resolve()
         except AttributeError:
             config_dir = pathlib.Path(config_dir).resolve()
 
-        factory = factory_class(
+        return factory_class(
             start_timeout=start_timeout or self.start_timeout,
             slow_stop=self.slow_stop,
             environ=self.environ,
             cwd=self.cwd,
             max_start_attempts=max_start_attempts,
             factories_manager=self,
-            cli_script_name="sshd",
+            cli_script_name=cli_script_name,
             display_name=display_name or "SSHD",
             config_dir=config_dir,
             listen_address=listen_address,
@@ -872,8 +534,6 @@ class FactoriesManager:
             sshd_config_dict=sshd_config_dict,
             **factory_class_kwargs
         )
-        self.cache["factories"][daemon_id] = factory
-        return factory
 
     def get_container(
         self,
@@ -912,7 +572,7 @@ class FactoriesManager:
             :py:class:`~saltfactories.factories.daemons.container.ContainerFactory`:
                 The factory instance
         """
-        factory = factory_class(
+        return factory_class(
             name=container_name,
             image=image_name,
             docker_client=docker_client,
@@ -923,15 +583,12 @@ class FactoriesManager:
             max_start_attempts=max_start_attempts,
             **factory_class_kwargs
         )
-        self.cache["factories"][container_name] = factory
-        return factory
 
     def _get_factory_class_instance(
         self,
         script_name,
         daemon_config,
         factory_class,
-        cache_key,
         daemon_id,
         max_start_attempts,
         start_timeout,
@@ -959,10 +616,9 @@ class FactoriesManager:
             cli_script_name=script_path,
             **factory_class_kwargs
         )
-        self.cache[cache_key][daemon_id] = factory
         return factory
 
-    def _get_root_dir_for_daemon(self, daemon_id, config_defaults=None):
+    def get_root_dir_for_daemon(self, daemon_id, config_defaults=None):
         if config_defaults and "root_dir" in config_defaults:
             try:
                 root_dir = pathlib.Path(config_defaults["root_dir"].strpath).resolve()
@@ -979,12 +635,3 @@ class FactoriesManager:
             counter += 1
         root_dir.mkdir(parents=True, exist_ok=True)
         return root_dir
-
-    def _handle_auth_event(self, master_id, payload):
-        self.pytestconfig.hook.pytest_saltfactories_handle_key_auth_event(
-            factories_manager=self,
-            master_id=master_id,
-            minion_id=payload["id"],
-            keystate=payload["act"],
-            payload=payload,
-        )
