@@ -1,4 +1,8 @@
 """
+..
+    PYTEST_DONT_REWRITE
+
+
     saltfactories.plugins.sysinfo
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -10,17 +14,10 @@ import pathlib
 import tempfile
 
 import pytest
-
-try:
-    import salt.config
-    import salt.loader
-    import salt.version
-    import salt.utils.yaml
-except ImportError:  # pragma: no cover
-    # We need salt to test salt with saltfactories, and, when pytest is rewriting modules for proper assertion
-    # reporting, we still haven't had a chance to inject the salt path into sys.modules, so we'll hit this
-    # import error, but its safe to pass
-    pass
+import salt.config
+import salt.loader
+import salt.utils.yaml
+import salt.version
 
 
 def pytest_addoption(parser):
